nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Ctrl2Set

Struct Ctrl2Set 

#[repr(transparent)]
pub struct Ctrl2Set(pub u32);
LCDIF General Control2 Register

Tuple Fields

0: u32

Implementations

Source

impl Ctrl2Set

pub const fn even_line_pattern(&self) -> Ctrl2SetEvenLinePattern

This field determines the order of the RGB components of each pixel in EVEN lines (line numbers 2,4,6,

pub const fn set_even_line_pattern(&mut self, val: Ctrl2SetEvenLinePattern)

This field determines the order of the RGB components of each pixel in EVEN lines (line numbers 2,4,6,

pub const fn odd_line_pattern(&self) -> Ctrl2SetOddLinePattern

This field determines the order of the RGB components of each pixel in ODD lines (line numbers 1,3,5,

pub const fn set_odd_line_pattern(&mut self, val: Ctrl2SetOddLinePattern)

This field determines the order of the RGB components of each pixel in ODD lines (line numbers 1,3,5,

pub const fn burst_len_8(&self) -> bool

By default, when the LCDIF is in the bus master mode, it will issue AXI bursts of length 16 (except when in packed 24 bpp mode, it will issue bursts of length 15)

pub const fn set_burst_len_8(&mut self, val: bool)

By default, when the LCDIF is in the bus master mode, it will issue AXI bursts of length 16 (except when in packed 24 bpp mode, it will issue bursts of length 15)

pub const fn outstanding_reqs(&self) -> Ctrl2SetOutstandingReqs

This bitfield indicates the maximum number of outstanding transactions that LCDIF should request when it is acting as a bus master

pub const fn set_outstanding_reqs(&mut self, val: Ctrl2SetOutstandingReqs)

This bitfield indicates the maximum number of outstanding transactions that LCDIF should request when it is acting as a bus master