#[repr(transparent)]pub struct Ctrl2Tog(pub u32);Expand description
LCDIF General Control2 Register
Tuple Fields
0: u32Implementations
Sourceimpl Ctrl2Tog
impl Ctrl2Tog
Sourcepub const fn even_line_pattern(&self) -> Ctrl2TogEvenLinePattern
pub const fn even_line_pattern(&self) -> Ctrl2TogEvenLinePattern
This field determines the order of the RGB components of each pixel in EVEN lines (line numbers 2,4,6,
Sourcepub const fn set_even_line_pattern(&mut self, val: Ctrl2TogEvenLinePattern)
pub const fn set_even_line_pattern(&mut self, val: Ctrl2TogEvenLinePattern)
This field determines the order of the RGB components of each pixel in EVEN lines (line numbers 2,4,6,
Sourcepub const fn odd_line_pattern(&self) -> Ctrl2TogOddLinePattern
pub const fn odd_line_pattern(&self) -> Ctrl2TogOddLinePattern
This field determines the order of the RGB components of each pixel in ODD lines (line numbers 1,3,5,
Sourcepub const fn set_odd_line_pattern(&mut self, val: Ctrl2TogOddLinePattern)
pub const fn set_odd_line_pattern(&mut self, val: Ctrl2TogOddLinePattern)
This field determines the order of the RGB components of each pixel in ODD lines (line numbers 1,3,5,
Sourcepub const fn burst_len_8(&self) -> bool
pub const fn burst_len_8(&self) -> bool
By default, when the LCDIF is in the bus master mode, it will issue AXI bursts of length 16 (except when in packed 24 bpp mode, it will issue bursts of length 15)
Sourcepub const fn set_burst_len_8(&mut self, val: bool)
pub const fn set_burst_len_8(&mut self, val: bool)
By default, when the LCDIF is in the bus master mode, it will issue AXI bursts of length 16 (except when in packed 24 bpp mode, it will issue bursts of length 15)
Sourcepub const fn outstanding_reqs(&self) -> Ctrl2TogOutstandingReqs
pub const fn outstanding_reqs(&self) -> Ctrl2TogOutstandingReqs
This bitfield indicates the maximum number of outstanding transactions that LCDIF should request when it is acting as a bus master
Sourcepub const fn set_outstanding_reqs(&mut self, val: Ctrl2TogOutstandingReqs)
pub const fn set_outstanding_reqs(&mut self, val: Ctrl2TogOutstandingReqs)
This bitfield indicates the maximum number of outstanding transactions that LCDIF should request when it is acting as a bus master