nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

CurBuf

Struct CurBuf 

#[repr(transparent)]
pub struct CurBuf(pub u32);
LCD Interface Current Buffer Address Register

Tuple Fields

0: u32

Implementations

Source

impl CurBuf

pub const fn addr(&self) -> u32

Address of the current frame being transmitted by LCDIF.

pub const fn set_addr(&mut self, val: u32)

Address of the current frame being transmitted by LCDIF.