#[repr(transparent)]pub struct Pigeon100(pub u32);Expand description
Panel Interface Signal Generator Register
Tuple Fields
0: u32Implementations
Sourceimpl Pigeon100
impl Pigeon100
Sourcepub const fn pol(&self) -> Pigeon100Pol
pub const fn pol(&self) -> Pigeon100Pol
Polarity of signal output
Sourcepub const fn set_pol(&mut self, val: Pigeon100Pol)
pub const fn set_pol(&mut self, val: Pigeon100Pol)
Polarity of signal output
Sourcepub const fn inc_sel(&self) -> Pigeon100IncSel
pub const fn inc_sel(&self) -> Pigeon100IncSel
Event to incrment local counter
Sourcepub const fn set_inc_sel(&mut self, val: Pigeon100IncSel)
pub const fn set_inc_sel(&mut self, val: Pigeon100IncSel)
Event to incrment local counter
Sourcepub const fn set_offset(&mut self, val: u8)
pub const fn set_offset(&mut self, val: u8)
offset on pclk unit
Sourcepub const fn mask_cnt_sel(&self) -> Pigeon100MaskCntSel
pub const fn mask_cnt_sel(&self) -> Pigeon100MaskCntSel
select global counters as mask condition, use together with MASK_CNT
Sourcepub const fn set_mask_cnt_sel(&mut self, val: Pigeon100MaskCntSel)
pub const fn set_mask_cnt_sel(&mut self, val: Pigeon100MaskCntSel)
select global counters as mask condition, use together with MASK_CNT
Sourcepub const fn mask_cnt(&self) -> u16
pub const fn mask_cnt(&self) -> u16
When the global counter selected through MASK_CNT_SEL matches value in this reg, pigeon local counter start ticking
Sourcepub const fn set_mask_cnt(&mut self, val: u16)
pub const fn set_mask_cnt(&mut self, val: u16)
When the global counter selected through MASK_CNT_SEL matches value in this reg, pigeon local counter start ticking
Sourcepub const fn state_mask(&self) -> Pigeon100StateMask
pub const fn state_mask(&self) -> Pigeon100StateMask
state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan states as reference point for local counter to start ticking
Sourcepub const fn set_state_mask(&mut self, val: Pigeon100StateMask)
pub const fn set_state_mask(&mut self, val: Pigeon100StateMask)
state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan states as reference point for local counter to start ticking