nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Pigeon42

Struct Pigeon42 

#[repr(transparent)]
pub struct Pigeon42(pub u32);
Panel Interface Signal Generator Register

Tuple Fields

0: u32

Implementations

Source

impl Pigeon42

pub const fn sig_logic(&self) -> Pigeon42SigLogic

Logic operation with another signal: DIS/AND/OR/COND

pub const fn set_sig_logic(&mut self, val: Pigeon42SigLogic)

Logic operation with another signal: DIS/AND/OR/COND

pub const fn sig_another(&self) -> Pigeon42SigAnother

Select another signal for logic operation or as mask or counter tick event

pub const fn set_sig_another(&mut self, val: Pigeon42SigAnother)

Select another signal for logic operation or as mask or counter tick event