nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Pigeon62

Struct Pigeon62 

#[repr(transparent)]
pub struct Pigeon62(pub u32);
Panel Interface Signal Generator Register

Tuple Fields

0: u32

Implementations

Source

impl Pigeon62

pub const fn sig_logic(&self) -> Pigeon62SigLogic

Logic operation with another signal: DIS/AND/OR/COND

pub const fn set_sig_logic(&mut self, val: Pigeon62SigLogic)

Logic operation with another signal: DIS/AND/OR/COND

pub const fn sig_another(&self) -> Pigeon62SigAnother

Select another signal for logic operation or as mask or counter tick event

pub const fn set_sig_another(&mut self, val: Pigeon62SigAnother)

Select another signal for logic operation or as mask or counter tick event