nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Pigeon90

Struct Pigeon90 

#[repr(transparent)]
pub struct Pigeon90(pub u32);
Panel Interface Signal Generator Register

Tuple Fields

0: u32

Implementations

Source

impl Pigeon90

pub const fn en(&self) -> bool

Enable pigeon Mode on this signal

pub const fn set_en(&mut self, val: bool)

Enable pigeon Mode on this signal

pub const fn pol(&self) -> Pigeon90Pol

Polarity of signal output

pub const fn set_pol(&mut self, val: Pigeon90Pol)

Polarity of signal output

pub const fn inc_sel(&self) -> Pigeon90IncSel

Event to incrment local counter

pub const fn set_inc_sel(&mut self, val: Pigeon90IncSel)

Event to incrment local counter

pub const fn offset(&self) -> u8

offset on pclk unit

pub const fn set_offset(&mut self, val: u8)

offset on pclk unit

pub const fn mask_cnt_sel(&self) -> Pigeon90MaskCntSel

select global counters as mask condition, use together with MASK_CNT

pub const fn set_mask_cnt_sel(&mut self, val: Pigeon90MaskCntSel)

select global counters as mask condition, use together with MASK_CNT

pub const fn mask_cnt(&self) -> u16

When the global counter selected through MASK_CNT_SEL matches value in this reg, pigeon local counter start ticking

pub const fn set_mask_cnt(&mut self, val: u16)

When the global counter selected through MASK_CNT_SEL matches value in this reg, pigeon local counter start ticking

pub const fn state_mask(&self) -> Pigeon90StateMask

state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan states as reference point for local counter to start ticking

pub const fn set_state_mask(&mut self, val: Pigeon90StateMask)

state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan states as reference point for local counter to start ticking