#[repr(transparent)]pub struct Stat(pub u32);Expand description
LCD Interface Status Register
Tuple Fields
0: u32Implementations
Sourceimpl Stat
impl Stat
Sourcepub const fn lfifo_count(&self) -> u16
pub const fn lfifo_count(&self) -> u16
Read only view of the current count in Latency buffer (LFIFO).
Sourcepub const fn set_lfifo_count(&mut self, val: u16)
pub const fn set_lfifo_count(&mut self, val: u16)
Read only view of the current count in Latency buffer (LFIFO).
Sourcepub const fn txfifo_empty(&self) -> bool
pub const fn txfifo_empty(&self) -> bool
Read only view of the signals that indicates LCD TXFIFO is empty.
Sourcepub const fn set_txfifo_empty(&mut self, val: bool)
pub const fn set_txfifo_empty(&mut self, val: bool)
Read only view of the signals that indicates LCD TXFIFO is empty.
Sourcepub const fn txfifo_full(&self) -> bool
pub const fn txfifo_full(&self) -> bool
Read only view of the signals that indicates LCD TXFIFO is full.
Sourcepub const fn set_txfifo_full(&mut self, val: bool)
pub const fn set_txfifo_full(&mut self, val: bool)
Read only view of the signals that indicates LCD TXFIFO is full.
Sourcepub const fn lfifo_empty(&self) -> bool
pub const fn lfifo_empty(&self) -> bool
Read only view of the signals that indicates LCD LFIFO is empty.
Sourcepub const fn set_lfifo_empty(&mut self, val: bool)
pub const fn set_lfifo_empty(&mut self, val: bool)
Read only view of the signals that indicates LCD LFIFO is empty.
Sourcepub const fn lfifo_full(&self) -> bool
pub const fn lfifo_full(&self) -> bool
Read only view of the signals that indicates LCD LFIFO is full.
Sourcepub const fn set_lfifo_full(&mut self, val: bool)
pub const fn set_lfifo_full(&mut self, val: bool)
Read only view of the signals that indicates LCD LFIFO is full.
Sourcepub const fn dma_req(&self) -> bool
pub const fn dma_req(&self) -> bool
Reflects the current state of the DMA Request line for the LCDIF
Sourcepub const fn set_dma_req(&mut self, val: bool)
pub const fn set_dma_req(&mut self, val: bool)
Reflects the current state of the DMA Request line for the LCDIF
Sourcepub const fn set_present(&mut self, val: bool)
pub const fn set_present(&mut self, val: bool)
0: LCDIF not present on this product 1: LCDIF is present.