#[repr(transparent)]pub struct TransferCount(pub u32);Expand description
LCDIF Horizontal and Vertical Valid Data Count Register
Tuple Fields
0: u32Implementations
Sourceimpl TransferCount
impl TransferCount
Sourcepub const fn set_h_count(&mut self, val: u16)
pub const fn set_h_count(&mut self, val: u16)
Total valid data (pixels) in each horizontal line
Sourcepub const fn v_count(&self) -> u16
pub const fn v_count(&self) -> u16
Number of horizontal lines per frame which contain valid data
Sourcepub const fn set_v_count(&mut self, val: u16)
pub const fn set_v_count(&mut self, val: u16)
Number of horizontal lines per frame which contain valid data