nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Vdctrl1

Struct Vdctrl1 

#[repr(transparent)]
pub struct Vdctrl1(pub u32);
LCDIF VSYNC Mode and Dotclk Mode Control Register1

Tuple Fields

0: u32

Implementations

Source

impl Vdctrl1

pub const fn vsync_period(&self) -> u32

Total number of units between two positive or two negative edges of the VSYNC signal

pub const fn set_vsync_period(&mut self, val: u32)

Total number of units between two positive or two negative edges of the VSYNC signal