nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Vdctrl2

Struct Vdctrl2 

#[repr(transparent)]
pub struct Vdctrl2(pub u32);
LCDIF VSYNC Mode and Dotclk Mode Control Register2

Tuple Fields

0: u32

Implementations

Source

impl Vdctrl2

pub const fn hsync_period(&self) -> u32

Total number of DISPLAY CLOCK (pix_clk) cycles between two positive or two negative edges of the HSYNC signal

pub const fn set_hsync_period(&mut self, val: u32)

Total number of DISPLAY CLOCK (pix_clk) cycles between two positive or two negative edges of the HSYNC signal

pub const fn hsync_pulse_width(&self) -> u16

Number of DISPLAY CLOCK (pix_clk) cycles for which HSYNC signal is active.

pub const fn set_hsync_pulse_width(&mut self, val: u16)

Number of DISPLAY CLOCK (pix_clk) cycles for which HSYNC signal is active.