#[repr(transparent)]pub struct Vdctrl1(pub u32);Expand description
LCDIF VSYNC Mode and Dotclk Mode Control Register1
Tuple Fields
0: u32Implementations
Sourceimpl Vdctrl1
impl Vdctrl1
Sourcepub const fn vsync_period(&self) -> u32
pub const fn vsync_period(&self) -> u32
Total number of units between two positive or two negative edges of the VSYNC signal
Sourcepub const fn set_vsync_period(&mut self, val: u32)
pub const fn set_vsync_period(&mut self, val: u32)
Total number of units between two positive or two negative edges of the VSYNC signal