#[repr(transparent)]pub struct Vdctrl2(pub u32);Expand description
LCDIF VSYNC Mode and Dotclk Mode Control Register2
Tuple Fields
0: u32Implementations
Sourceimpl Vdctrl2
impl Vdctrl2
Sourcepub const fn hsync_period(&self) -> u32
pub const fn hsync_period(&self) -> u32
Total number of DISPLAY CLOCK (pix_clk) cycles between two positive or two negative edges of the HSYNC signal
Sourcepub const fn set_hsync_period(&mut self, val: u32)
pub const fn set_hsync_period(&mut self, val: u32)
Total number of DISPLAY CLOCK (pix_clk) cycles between two positive or two negative edges of the HSYNC signal
Sourcepub const fn hsync_pulse_width(&self) -> u16
pub const fn hsync_pulse_width(&self) -> u16
Number of DISPLAY CLOCK (pix_clk) cycles for which HSYNC signal is active.
Sourcepub const fn set_hsync_pulse_width(&mut self, val: u16)
pub const fn set_hsync_pulse_width(&mut self, val: u16)
Number of DISPLAY CLOCK (pix_clk) cycles for which HSYNC signal is active.